==> tmtccmd-7.0.0.tar.gz: tmtccmd-7.0.0/tmtccmd/pus/tm/s2_rawcmd.py <==
"""Base class for implementation of PUS Service 2 handling.
"""
from __future__ import annotations

from typing import Optional

import deprecation

from spacepackets.ccsds.time import CcsdsTimeProvider
from spacepackets.ecss.tm import CdsShortTimestamp, PusTelemetry

from tmtccmd.version import get_version
from tmtccmd.tmtc.base import PusTmInfoBase, PusTmBase


class Service2Tm(PusTmInfoBase, PusTmBase):
    @deprecation.deprecated(
        deprecated_in="v4.0.0a1",
        current_version=get_version(),
        details="use a custom wrapper type instead",
    )
    def __init__(
        self,
        subservice: int,
        time: Optional[CdsShortTimestamp] = None,
        ssc: int = 0,
        source_data: bytearray = bytearray([]),
        apid: int = -1,
        packet_version: int = 0b000,
        space_time_ref: int = 0b0000,
        destination_id: int = 0,
    ):
        pus_tm = PusTelemetry(
            service=2,
            subservice=subservice,
            time_provider=time,
            seq_count=ssc,
            source_data=source_data,
            apid=apid,
            packet_version=packet_version,
            space_time_ref=space_time_ref,
            destination_id=destination_id,
        )
        PusTmInfoBase.__init__(self, pus_tm=pus_tm)
        PusTmBase.__init__(self, pus_tm=pus_tm)
        self.set_packet_info("Raw Commanding Reply")

    @classmethod
    def __empty(cls) -> Service2Tm:
        return cls(subservice=0)

    @classmethod
    def unpack(
        cls, raw_telemetry: bytes, time_reader: Optional[CcsdsTimeProvider]
    ) -> Service2Tm:
        service_2_tm = cls.__empty()
        service_2_tm.pus_tm = PusTelemetry.unpack(
            data=raw_telemetry, time_reader=time_reader
        )
        return service_2_tm

    def append_telemetry_content(self, content_list: list):
        super().append_telemetry_content(content_list=content_list)

    def append_telemetry_column_headers(self, header_list: list):
        super().append_telemetry_column_headers(header_list=header_list)

==> tmtccmd-8.0.0rc2.tar.gz: tmtccmd-8.0.0rc2/tmtccmd/pus/tm/s2_rawcmd.py <==
"""Base class for implementation of PUS Service 2 handling.
"""

from __future__ import annotations

from typing import Optional

from deprecated.sphinx import deprecated
from spacepackets.ccsds.time import CcsdsTimeProvider
from spacepackets.ecss.tm import CdsShortTimestamp, PusTelemetry

from tmtccmd.tmtc.tm_base import PusTmBase, PusTmInfoBase


class Service2Tm(PusTmInfoBase, PusTmBase):
    @deprecated(
        version="v4.0.0a1",
        reason="use a custom wrapper type instead",
    )
    def __init__(
        self,
        subservice: int,
        time: Optional[CdsShortTimestamp] = None,
        ssc: int = 0,
        source_data: bytearray = bytearray([]),
        apid: int = -1,
        packet_version: int = 0b000,
        space_time_ref: int = 0b0000,
        destination_id: int = 0,
    ):
        pus_tm = PusTelemetry(
            service=2,
            subservice=subservice,
            time_provider=time,
            seq_count=ssc,
            source_data=source_data,
            apid=apid,
            packet_version=packet_version,
            space_time_ref=space_time_ref,
            destination_id=destination_id,
        )
        PusTmInfoBase.__init__(self, pus_tm=pus_tm)
        PusTmBase.__init__(self, pus_tm=pus_tm)
        self.set_packet_info("Raw Commanding Reply")

    @classmethod
    def __empty(cls) -> Service2Tm:
        return cls(subservice=0)

    @classmethod
    def unpack(
        cls, raw_telemetry: bytes, time_reader: Optional[CcsdsTimeProvider]
    ) -> Service2Tm:
        service_2_tm = cls.__empty()
        service_2_tm.pus_tm = PusTelemetry.unpack(
            data=raw_telemetry, time_reader=time_reader
        )
        return service_2_tm

    def append_telemetry_content(self, content_list: list):
        super().append_telemetry_content(content_list=content_list)

    def append_telemetry_column_headers(self, header_list: list):
        super().append_telemetry_column_headers(header_list=header_list)
